package de.ullisroboterseite.ursanalogclock;

// Autor: https://UllisRoboterSeite.de

// Doku:  https://UllisRoboterSeite.de/android-AI2-visible.html
// Created: 2020-12-12
//
// Version 1 (2020-12-12)
// -------------------------
// - Basis-Version

import com.google.appinventor.components.annotations.*;
import com.google.appinventor.components.annotations.androidmanifest.*;
import com.google.appinventor.components.common.*;
import com.google.appinventor.components.runtime.*;
import com.google.appinventor.components.runtime.util.*;

import android.view.View;
import android.util.Log;

/**
 * Dies ist die nicht sichtbare Komponente, ein Wrapper für die sichtbare Komponente
 */
@DesignerComponent(version = 1, //
      versionName = "1.0", //
      dateBuilt = "2020-12-13", //
      description = "AI2 extension Analog clock component.", //
      category = com.google.appinventor.components.common.ComponentCategory.EXTENSION, //
      nonVisible = true, //
      helpUrl = "http://UllisRoboterSeite.de/android-AI2-visible.html", //
      iconName = "aiwebres/icon.png")
@SimpleObject(external = true)
public class UrsAnalogClock extends UrsViewBase {
   static final String LOG_TAG = UrsViewBase.LOG_TAG;
   UrsClockComponent ursClockComponent = null;
   PropertyBackup<Integer> backgroundColor = new PropertyBackup<Integer>(80);
   PropertyBackup<Integer> width = new PropertyBackup<Integer>(80);
   PropertyBackup<Integer> height = new PropertyBackup<Integer>(0);

   /**
    * Initialisiert eine neue Instanz der UrsAnalogClock-Klasse
    * @param container Die Übergeordnete Komponente.
    * @note Da es sich um eine nicht sichtbare Komponente handelt, ist der container der übergeordnete Screen.
    */
   public UrsAnalogClock(ComponentContainer container) {
      super(container);
   }

   /**
   * Erstellt die sichtbare Komponente mit einer AnalogClock-View.
   * @param visibleContainer Der Container, in die die Komponente eingebunden werden soll.
   * @param placeholder Die Komponente, die ersetzt werden soll (z.B. zur Übernahme von Eigenschaften)
   * @return Eine Instanz der sichtbaren Komponente.
   * @note Es werden Width, Height und BackgroundColor vom Platzhalter übernommen.
   */
   AndroidViewComponent createViewComponent(ComponentContainer visibleContainer, Button placeholder) {
      ursClockComponent = new UrsClockComponent(visibleContainer);
      return ursClockComponent;
   }

   /**
   * Wird ausgelöst, wenn die Ersetzung stattgefunden hat.
   * @param container Der Container der neu erstellten Komponente
   * @param placeholder Der Platzhalter
   * @note Width und Height werden über den Container eingestellt und
   * kann deshalb erst nach dem Ersatz festgelegt werden.
   */
  @Override
   void replacementDone(ComponentContainer container, Button placeholder) {
      ursClockComponent.Width(width.getAndReplaceValue(placeholder.Width()));
      ursClockComponent.Height(height.getAndReplaceValue(placeholder.Height()));
      ursClockComponent.setBackgroundColor(backgroundColor.getAndReplaceValue(placeholder.BackgroundColor()));
   }

   /**
   * Returns the component's background color as an alpha-red-green-blue integer.
   * @return  background RGB color with alpha
   */
   @SimpleProperty(category = PropertyCategory.APPEARANCE, description = "Returns the component's background color")
   @IsColor
   public int BackgroundColor() {
      return backgroundColor.getValue();
   }

   /**
   * Specifies the component's background color as an alpha-red-green-blue integer.
   * @param argb background RGB color with alpha
   */
   @SimpleProperty(description = "Specifies the background color of the component.")
   public void BackgroundColor(int argb) {
      backgroundColor.setValue(argb);
      if (ursClockComponent != null) // Zur Zeit von Screen.Initialize ist die Komponente noch nicht angelegt.
         ursClockComponent.setBackgroundColor(argb);
   }

   /**
   * Returns the component's vertical height, measured in pixels.
   * @return  height in pixels
   */
   @SimpleProperty(category = PropertyCategory.APPEARANCE, description = "Returns the component's vertical height, measured in pixels")
   public int Height() {
      return height.getValue();
   }

   /**
   * Specifies the component's vertical height, measured in pixels.
   * @param  value in pixels
   */
   @SimpleProperty(description = "Specifies the vertical height of the component, measured in pixels.")
   public void Height(int value) {
      height.setValue(value);
      if (ursClockComponent != null) // Zur Zeit von Screen.Initialize ist die Komponente noch nicht angelegt.
         ursClockComponent.Height(value);

   }

   /**
   * Returns the horizontal width of the component, measured in pixels.
   * @return  width in pixels
   */
   @SimpleProperty(category = PropertyCategory.APPEARANCE, description = "Returns the component's horizontal width, measured in pixels")
   public int Width() {
      return width.getValue();
   }

   /**
   * Specifies the horizontal width of the component, measured in pixels.
   * @param  value in pixels
   */
   @SimpleProperty(description = "Specifies the horizontal width of the component, measured in pixels.")
   public void Width(int value) {
      width.setValue(value);
      if (ursClockComponent != null) // Zur Zeit von Screen.Initialize ist die Komponente noch nicht angelegt.
         ursClockComponent.Width(value);
   }
}